==> egroupware_1.2-105.dfsg.orig.tar.gz: egroupware-1.2-105.dfsg/resources/setup/setup.inc.php <==
<?php
	/**
	 * eGroupWare - resources
	 * http://www.egroupware.org 
	 *
	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
	 * @package resources
	 * @author Cornelius Weiss <egw@von-und-zu-weiss.de>
	 * @author Lukas Weiss <wnz_gh05t@users.sourceforge.net>
	 * @version $Id: setup.inc.php 19821 2005-11-14 18:16:56Z nelius_weiss $
	 */
	
	$setup_info['resources']['name']	= 'resources';
	$setup_info['resources']['title']	= 'Resources';
	$setup_info['resources']['version']	= '1.2';
	$setup_info['resources']['app_order']	= 5;
	$setup_info['resources']['tables']	= array('egw_resources','egw_resources_extra');
	$setup_info['resources']['enable']	= 1;

	$setup_info['resources']['author']	= 'Cornelius Weiss'; 
	$setup_info['resources']['license']	= 'GPL'; 
	$setup_info['resources']['description'] = 'A resource management and booking system, which integrates into eGroupWare\'s calendar.';
	$setup_info['resources']['note']	= '';
	$setup_info['resources']['maintainer']	= array( 
		'name' => 'Cornelius Weiss', 
		'email' => 'egw@von-und-zu-weiss.de' 
	); 
		
	$setup_info['resources']['hooks']['preferences']	= 'resources.resources_hooks.admin_prefs_sidebox';
	$setup_info['resources']['hooks']['admin']		= 'resources.resources_hooks.admin_prefs_sidebox';
	$setup_info['resources']['hooks']['sidebox_menu']	= 'resources.resources_hooks.admin_prefs_sidebox';
	$setup_info['resources']['hooks']['search_link']	= 'resources.resources_hooks.search_link';
	$setup_info['resources']['hooks']['calendar_resources']	= 'resources.resources_hooks.calendar_resources';
//	$setup_info['resources']['hooks'][]	= 'home';
//	$setup_info['resources']['hooks'][]	= 'settings';

	$setup_info['resources']['depends'][]	= array(
		 'appname' => 'phpgwapi',
		 'versions' => Array('1.0.1','1.2')
	);
	$setup_info['resources']['depends'][]	= array( // cause eTemplates is not in the api yet
		 'appname' => 'etemplate',
		 'versions' => Array('1.0.1','1.2')
	);
	$setup_info['resources']['depends'][]	= array( // cause of vfs psuedoprotocol is not fully in the api yet
		 'appname' => 'filemanager',
		 'versions' => Array('1.0.0','1.0.1','1.2')
	);

==> egroupware_1.4.004-2.dfsg.orig.tar.gz: egroupware-1.4.004-2.dfsg/resources/setup/setup.inc.php <==
<?php
	/**
	 * eGroupWare - resources
	 * http://www.egroupware.org 
	 *
	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
	 * @package resources
	 * @subpackage setup
	 * @author Cornelius Weiss <egw@von-und-zu-weiss.de>
	 * @author Lukas Weiss <wnz_gh05t@users.sourceforge.net>
	 * @version $Id: setup.inc.php 23741 2007-04-30 10:29:44Z lkneschke $
	 */
	
	$setup_info['resources']['name']	= 'resources';
	$setup_info['resources']['title']	= 'Resources';
	$setup_info['resources']['version']	= '1.4';
	$setup_info['resources']['app_order']	= 5;
	$setup_info['resources']['tables']	= array('egw_resources','egw_resources_extra');
	$setup_info['resources']['enable']	= 1;

	$setup_info['resources']['author']	= 'Cornelius Weiss'; 
	$setup_info['resources']['license']	= 'GPL'; 
	$setup_info['resources']['description'] = 'A resource management and booking system, which integrates into eGroupWare\'s calendar.';
	$setup_info['resources']['note']	= '';
	$setup_info['resources']['maintainer']	= array( 
		'name' => 'Cornelius Weiss', 
		'email' => 'egw@von-und-zu-weiss.de' 
	); 
		
	$setup_info['resources']['hooks']['preferences']	= 'resources.resources_hooks.admin_prefs_sidebox';
	$setup_info['resources']['hooks']['admin']		= 'resources.resources_hooks.admin_prefs_sidebox';
	$setup_info['resources']['hooks']['sidebox_menu']	= 'resources.resources_hooks.admin_prefs_sidebox';
	$setup_info['resources']['hooks']['search_link']	= 'resources.resources_hooks.search_link';
	$setup_info['resources']['hooks']['calendar_resources']	= 'resources.resources_hooks.calendar_resources';
//	$setup_info['resources']['hooks'][]	= 'home';
//	$setup_info['resources']['hooks'][]	= 'settings';

	$setup_info['resources']['depends'][]	= array(
		 'appname' => 'phpgwapi',
		 'versions' => Array('1.3','1.4','1.5')
	);
	$setup_info['resources']['depends'][]	= array( // cause eTemplates is not in the api yet
		 'appname' => 'etemplate',
		 'versions' => Array('1.3','1.4','1.5')
	);
	$setup_info['resources']['depends'][]	= array( // cause of vfs psuedoprotocol is not fully in the api yet
		 'appname' => 'filemanager',
		 'versions' => Array('1.3','1.4','1.5')
	);
